@@ -119,11 +119,12 @@ class Phonepatch:
 		self.sox_pars = "-t raw -c%d -w -s" %self.asterisk_channels
 		
 		# Festival (audio-to-speech generator) options
-		#self.festival_isotolang = {"es": "spanish", "cy": "welsh"}
-		self.festival_isotolang = {}
+		#self.festival_isotolang = {}
+		self.festival_isotolang = {"es": "spanish", "cy": "welsh"}
 			
 		# Configuration options
 		self.festival_indicator = "@"
+		self.last_playargs = None
 		
 		# Create signals dictionary: key = signal_int - value = signal_name
 		self.signals = {}
@@ -377,20 +378,18 @@ class Phonepatch:
 		
 		if play_radio: self.debug("play: playing to soundcard: %s" %str(args))
 		if play_asterisk: self.debug("play: playing to asterisk: %s" %str(args))
-		try: last_playargs = self.last_playargs
-		except: last_playargs = None
+		try: args = args.strip().replace("%u", self.getconf("username"))
+		except: pass
 			
 		# args: file | @texttospeech, separed by commas.
-		if args == last_playargs: 
+		if args == self.last_playargs: 
 			# It's the same, so using cached audio data
 			self.debug("play: using cached audio")
 		else:
 			# Load args (play_file() for audiofiles and play_text() for text-to-speech)
 			self.raw_data = ""
-			for option in args.split(","):
+			for option in [s.strip() for s in args.split(",")]:
 				if not option: continue
-				try: option = option.strip().replace("%u", self.destination)
-				except: pass
 				if option[0] == self.festival_indicator:
 					self.raw_data += self.play_text(option[len(self.festival_indicator):])
 				else: self.raw_data += self.play_file(option)
@@ -611,7 +610,7 @@ class Phonepatch:
 		s = rfile.readline().strip().split("|")
 		self.debug("control_handler: received: %s"%s)
 		if len(s) == 2 and s[0] == "incall":
-			command, self.destination = s
+			command, self.phonepatch_extension = s
 		elif len(s) == 1 and s[0] == "outcall":
 			command = s
 		else:
@@ -711,7 +710,7 @@ class Phonepatch:
 			return
 		while 1:
 			# TODO: fullduplex
-			if self.play(True, True, self.getconf("incall_report_audio")) == None: 
+			if self.play(True, True, self.getconf("incall_report_audio")) is None:
 				self.debug("process_incall: play() ended abnormally")
 				return			
 			if not mode or mode == "open": 
@@ -806,7 +805,7 @@ class Phonepatch:
 		callerid = self.getconf("callerid")
 		if not callerid:
 			callerid = "%s <%s>" %(self.getconf("username"), self.phonepatch_extension)
-		self.debug("make_call: phonepatch: %s (%s) - destination: %s" %(self.phonepatch_extension, self.asterisk_extension, number))
+		self.debug("make_call: phonepatch: %s (%s) - number: %s" %(self.phonepatch_extension, self.asterisk_extension, number))
 		channel = self.getconf("outcall_channel").replace("%x", number)		
 		account = OUTCALL_IDNAME
 		
@@ -975,7 +974,7 @@ class Phonepatch:
 
 			self.set_ctcss_tx()
 			
-			# AskForTone DTMF button received, now record the destination number
+			# AskForTone DTMF button received, now record the number
 			# TODO: Fullduplex
 			if not self.check_asterisk_active():
 				self.play(True, False, self.getconf("asterisk_inactive_audio"))
@@ -1006,7 +1005,7 @@ class Phonepatch:
 				if self.getconf("outcall_button") in dtmf_keys: 
 					self.accept_agicalls = False
 					dtmf_keys = dtmf_keys[:dtmf_keys.index(self.getconf("outcall_button"))]
-					if not dtmf_keys: self.debug("loop_daemon: destination number void"); continue
+					if not dtmf_keys: self.debug("loop_daemon: number void"); continue
 					# We have a number (in a list) to call to, convert to string
 					number = "".join(dtmf_keys)
 					noisy_button = self.getconf("dtmf_noisy_mode_button")
